<?php

App::uses('User', 'Model');

class Customer extends User {

	public $useTable = 'users';

	const CUSTOMER_USER_GROUP=3;

	public function validateRegister() {

		$rules = $this->validate;

		$rules['accept_terms'] = array(
			'rule' => array('equalTo', '1'), 
			'message' => 'Please read and accept the Terms & Conditions'
		);

		$rules['confirm_password']['required']['message'] = 'Please confirm password';

		unset($rules['user_group_id']);

		return $rules;

	}


/**
 * Handles user registration 
 * @param  array $userData 	The array of new user data
 * @return int         		New User Id if success else returns false
 */
	public function register($userData) {

		$this->validate = $this->validateRegister();
		$userData[$this->alias]['user_group_id'] = self::CUSTOMER_USER_GROUP;
		$userData[$this->alias]['is_active'] = 1;

		// If guest user we need to check if there already is an account and 
		// if there is we need to log them in as that user instead of registering a new one
		if ($userData[$this->alias]['checkout_as_guest'] == 1) {

			$userData[$this->alias]['is_guest_user'] = 1;

			$existingUser = $this->find('first', array(
					'conditions' => array(
						$this->alias.'.email' => $userData[$this->alias]['email'], 
						$this->alias.'.user_group_id' => self::CUSTOMER_USER_GROUP, //Need to ensure it is also a customer otherwise would allow them to change the details of an admin user
						$this->alias.'.is_guest_user' => true //If not a guest user and the email address is already in the system they will get a message telling them they are already registered
					)
				)
			);

			if (!empty($existingUser)) {

				// User exists log in as this user and update details
				$this->id = $existingUser[$this->alias]['id'];

			}

			//As they are a guest we dont need to validate or save the password fields
			unset($this->validate['password']);
			unset($this->validate['confirm_password']);
			unset($userData[$this->alias]['password']);
			unset($userData[$this->alias]['confirm_password']);

		}



		//Update or create user
		$this->set($userData);
		if($this->save()) {

			return $this->id; 

		} else {

			return false; 

		}

	}

/**
 * Gets the user and all associated data out that is needed for login
 * @param  int $id  The ID of the user
 * @return array 	User array
 */
	public function getUserForLogin($id) {

		$fullUser = $this->find('first', array(
				'conditions' => array(
					$this->alias.'.id' => $id
				),
				'contain'=> array(
					'UserGroup'
				)
			)
		);

		//Swap out Customer for User
		$fullUser['User'] = $fullUser['Customer'];
		unset($fullUser['Customer']);

		return $fullUser; 

	}

}